/** @format */
/* eslint-env node */

var ICAL = require("ical.js");

var _require = require("../package.json"),
    icalMerger = _require.icalMerger;

function fullCalendarEventsToIcs(events) {
	var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

	var calendar = new ICAL.Component(["vcalendar", [], []]);

	calendar.updatePropertyWithValue("prodid", icalMerger.prodid);
	calendar.updatePropertyWithValue("version", icalMerger.version);

	var tzid = options.timezone;


	if (!tzid) {
		var moment = require('moment-timezone');
		tzid = moment.tz.guess();
	}
	calendar.updatePropertyWithValue("x-wr-timezone", tzid);

	var vtimezone = new ICAL.Component('vtimezone');
	var timezone = new ICAL.Timezone({
		component: vtimezone,
		tzid: tzid
	});

	if (options.calname) calendar.updatePropertyWithValue("x-wr-calname", options.calname);

	if (options.caldesc) calendar.updatePropertyWithValue("x-wr-caldesc", options.caldesc);

	var _iteratorNormalCompletion = true;
	var _didIteratorError = false;
	var _iteratorError = undefined;

	try {
		for (var _iterator = events[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
			var fcEvent = _step.value;

			var vevent = new ICAL.Component("vevent");
			var event = new ICAL.Event(vevent);

			event.startDate = new ICAL.Time(getTimeData(fcEvent.start), timezone);
			event.endDate = new ICAL.Time(getTimeData(fcEvent.end), timezone);
			event.description = fcEvent.title;
			event.uid = fcEvent.id;

			calendar.addSubcomponent(vevent);
		}
	} catch (err) {
		_didIteratorError = true;
		_iteratorError = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion && _iterator.return) {
				_iterator.return();
			}
		} finally {
			if (_didIteratorError) {
				throw _iteratorError;
			}
		}
	}

	return calendar.toString();
}

function getTimeData(date) {
	date = new Date(date);
	return {
		year: date.getFullYear(),
		month: date.getMonth() + 1,
		day: date.getDate(),
		hour: date.getHours(),
		minute: date.getMinutes(),
		second: date.getSeconds()
	};
}

module.exports = fullCalendarEventsToIcs;
